@@ -1,14 +1,14 @@
 #This file is part of Tryton.  The COPYRIGHT file at the top level of
 #this repository contains the full copyright notices and license terms.
-from __future__ import with_statement
 from trytond.model import ModelView, ModelSQL, fields
 from trytond.wizard import Wizard
 from trytond.backend import TableHandler
-from trytond.pyson import Equal, Eval, Not, Get, Or, And, Bool
+from trytond.pyson import Eval, Bool
 from trytond.transaction import Transaction
+from trytond.pool import Pool
 
 STATES = {
-    'readonly': Equal(Eval('state'), 'close'),
+    'readonly': Eval('state') == 'close',
 }
 DEPENDS = ['state']
 
@@ -87,33 +87,33 @@ class Journal(ModelSQL, ModelView):
     centralised = fields.Boolean('Centralised counterpart')
     update_posted = fields.Boolean('Allow cancelling moves')
     sequence = fields.Property(fields.Many2One('ir.sequence', 'Sequence',
-        domain=[('code', '=', 'account.journal')],
-        context={'code': 'account.journal'},
-        states={
-            'required': Bool(Get(Eval('context', {}), 'company', 0)),
-        }))
+            domain=[('code', '=', 'account.journal')],
+            context={'code': 'account.journal'},
+            states={
+                'required': Bool(Eval('context', {}).get('company', 0)),
+                }))
     credit_account = fields.Property(fields.Many2One('account.account',
-        'Default Credit Account', domain=[
-            ('kind', '!=', 'view'),
-            ('company', '=', Get(Eval('context', {}), 'company', 0)),
-        ],
-        states={
-            'required': And(Or(Bool(Eval('centralised')),
-                Equal(Eval('type'), 'cash')),
-                Bool(Get(Eval('context', {}), 'company', 0))),
-            'invisible': Not(Bool(Get(Eval('context', {}), 'company', 0))),
-        }, depends=['type', 'centralised']))
+            'Default Credit Account', domain=[
+                ('kind', '!=', 'view'),
+                ('company', '=', Eval('context', {}).get('company', 0)),
+                ],
+            states={
+                'required': ((Eval('centralised', False)
+                        | (Eval('type') == 'cash'))
+                    & Bool(Eval('context', {}).get('company', 0))),
+                'invisible': ~Eval('context', {}).get('company', 0),
+                }, depends=['type', 'centralised']))
     debit_account = fields.Property(fields.Many2One('account.account',
-        'Default Debit Account', domain=[
-            ('kind', '!=', 'view'),
-            ('company', '=', Get(Eval('context', {}), 'company', 0)),
-        ],
-        states={
-            'required': And(Or(Bool(Eval('centralised')),
-                Equal(Eval('type'), 'cash')),
-                Bool(Get(Eval('context', {}), 'company', 0))),
-            'invisible': Not(Bool(Get(Eval('context', {}), 'company', 0))),
-        }, depends=['type', 'centralised']))
+            'Default Debit Account', domain=[
+                ('kind', '!=', 'view'),
+                ('company', '=', Eval('context', {}).get('company', 0)),
+                ],
+            states={
+                'required': ((Eval('centralised', False)
+                        | (Eval('type') == 'cash'))
+                    & Bool(Eval('context', {}).get('company', 0))),
+                'invisible': ~Eval('context', {}).get('company', 0),
+                }, depends=['type', 'centralised']))
 
     def __init__(self):
         super(Journal, self).__init__()
@@ -126,7 +126,7 @@ class Journal(ModelSQL, ModelView):
 
         # Migration from 1.0 sequence Many2One change into Property
         if table.column_exist('sequence'):
-            property_obj = self.pool.get('ir.property')
+            property_obj = Pool().get('ir.property')
             cursor.execute('SELECT id, sequence FROM "' + self._table +'"')
             with Transaction().set_user(0):
                 for journal_id, sequence_id in cursor.fetchall():
@@ -148,7 +148,7 @@ class Journal(ModelSQL, ModelView):
         return False
 
     def get_types(self):
-        type_obj = self.pool.get('account.journal.type')
+        type_obj = Pool().get('account.journal.type')
         type_ids = type_obj.search([])
         types = type_obj.browse(type_ids)
         return [(x.code, x.name) for x in types]
@@ -210,7 +210,7 @@ class Period(ModelSQL, ModelView):
         return res
 
     def _check(self, ids):
-        move_obj = self.pool.get('account.move')
+        move_obj = Pool().get('account.move')
         for period in self.browse(ids):
             move_ids = move_obj.search([
                 ('journal', '=', period.journal.id),
@@ -221,7 +221,7 @@ class Period(ModelSQL, ModelView):
         return
 
     def create(self, vals):
-        period_obj = self.pool.get('account.period')
+        period_obj = Pool().get('account.period')
         if vals.get('period'):
             period = period_obj.browse(vals['period'])
             if period.state == 'close':
@@ -269,7 +269,7 @@ class ClosePeriod(Wizard):
     }
 
     def _close(self, data):
-        journal_period_obj = self.pool.get('account.journal.period')
+        journal_period_obj = Pool().get('account.journal.period')
         journal_period_obj.close(data['ids'])
         return {}
 
@@ -290,7 +290,7 @@ class ReOpenPeriod(Wizard):
     }
 
     def _reopen(self, data):
-        journal_period_obj = self.pool.get('account.journal.period')
+        journal_period_obj = Pool().get('account.journal.period')
         journal_period_obj.write(data['ids'], {
             'state': 'open',
             })
