@@ -1,14 +1,13 @@
 #This file is part of Tryton.  The COPYRIGHT file at the top level of
 #this repository contains the full copyright notices and license terms.
-from __future__ import with_statement
 from decimal import Decimal
 from trytond.model import ModelView, ModelSQL, fields
 from trytond.wizard import Wizard
 from trytond.backend import TableHandler
-from trytond.pyson import Eval, Not, Equal, If, In, Bool, Get, Or, And, \
-        PYSONEncoder
+from trytond.pyson import Eval, If, Bool, PYSONEncoder
 from trytond.transaction import Transaction
 from trytond.cache import Cache
+from trytond.pool import Pool
 
 
 class Group(ModelSQL, ModelView):
@@ -89,8 +88,8 @@ class CodeTemplate(ModelSQL, ModelView):
                 must be created
         :return: id of the tax code created
         '''
-        tax_code_obj = self.pool.get('account.tax.code')
-        lang_obj = self.pool.get('ir.lang')
+        tax_code_obj = Pool().get('account.tax.code')
+        lang_obj = Pool().get('ir.lang')
 
         if template2tax_code is None:
             template2tax_code = {}
@@ -175,7 +174,7 @@ class Code(ModelSQL, ModelView):
         return Transaction().context.get('company') or False
 
     def on_change_with_currency_digits(self, vals):
-        company_obj = self.pool.get('company.company')
+        company_obj = Pool().get('company.company')
         if vals.get('company'):
             company = company_obj.browse(vals['company'])
             return company.currency.digits
@@ -190,8 +189,8 @@ class Code(ModelSQL, ModelView):
     def get_sum(self, ids, name):
         cursor = Transaction().cursor
         res = {}
-        move_line_obj = self.pool.get('account.move.line')
-        currency_obj = self.pool.get('currency.currency')
+        move_line_obj = Pool().get('account.move.line')
+        currency_obj = Pool().get('currency.currency')
 
         child_ids = self.search([('parent', 'child_of', ids)])
         all_ids = {}.fromkeys(ids + child_ids).keys()
@@ -261,8 +260,8 @@ class Code(ModelSQL, ModelView):
                 and tax code id as value, used to convert template id into
                 tax code. The dictionary is filled with new tax codes
         '''
-        template_obj = self.pool.get('account.tax.code.template')
-        lang_obj = self.pool.get('ir.lang')
+        template_obj = Pool().get('account.tax.code.template')
+        lang_obj = Pool().get('ir.lang')
 
         if template2tax_code is None:
             template2tax_code = {}
@@ -311,14 +310,14 @@ class OpenChartCodeInit(ModelView):
         ('periods', 'By Periods'),
         ], 'Method', required=True)
     fiscalyear = fields.Many2One('account.fiscalyear', 'Fiscal Year',
-            help='Leave empty for all open fiscal year',
-            states={
-                'invisible': Not(Equal(Eval('method'), 'fiscalyear')),
+        help='Leave empty for all open fiscal year',
+        states={
+            'invisible': Eval('method') != 'fiscalyear',
             }, depends=['method'])
     periods = fields.Many2Many('account.period', None, None, 'Periods',
-            help='Leave empty for all periods of all open fiscal year',
-            states={
-                'invisible': Not(Equal(Eval('method'), 'periods')),
+        help='Leave empty for all periods of all open fiscal year',
+        states={
+            'invisible': Eval('method') != 'periods',
             }, depends=['method'])
 
     def default_method(self):
@@ -351,8 +350,8 @@ class OpenChartCode(Wizard):
     }
 
     def _action_open_chart(self, data):
-        model_data_obj = self.pool.get('ir.model.data')
-        act_window_obj = self.pool.get('ir.action.act_window')
+        model_data_obj = Pool().get('ir.model.data')
+        act_window_obj = Pool().get('ir.action.act_window')
         act_window_id = model_data_obj.get_id('account', 'act_tax_code_tree2')
         res = act_window_obj.read(act_window_id)
         if data['form']['method'] == 'fiscalyear':
@@ -478,8 +477,8 @@ class TaxTemplate(ModelSQL, ModelView):
                 created
         :return: id of the tax created
         '''
-        tax_obj = self.pool.get('account.tax')
-        lang_obj = self.pool.get('ir.lang')
+        tax_obj = Pool().get('account.tax')
+        lang_obj = Pool().get('ir.lang')
 
         if template2tax is None:
             template2tax = {}
@@ -581,12 +580,13 @@ class Tax(ModelSQL, ModelView):
     currency_digits = fields.Function(fields.Integer('Currency Digits',
         on_change_with=['company']), 'get_currency_digits')
     amount = fields.Numeric('Amount', digits=(16, Eval('currency_digits', 2)),
-            states={
-                'invisible': Not(Equal(Eval('type'), 'fixed')),
-            }, help='In company\'s currency', depends=['type', 'currency_digits'])
+        states={
+            'invisible': Eval('type') != 'fixed',
+            }, help='In company\'s currency',
+        depends=['type', 'currency_digits'])
     percentage = fields.Numeric('Percentage', digits=(16, 8),
-            states={
-                'invisible': Not(Equal(Eval('type'), 'percentage')),
+        states={
+            'invisible': Eval('type') != 'percentage',
             }, help='In %', depends=['type'])
     type = fields.Selection([
         ('percentage', 'Percentage'),
@@ -596,72 +596,69 @@ class Tax(ModelSQL, ModelView):
     parent = fields.Many2One('account.tax', 'Parent', ondelete='CASCADE')
     childs = fields.One2Many('account.tax', 'parent', 'Children')
     company = fields.Many2One('company.company', 'Company', required=True,
-            domain=[
-                ('id', If(In('company', Eval('context', {})), '=', '!='),
-                    Get(Eval('context', {}), 'company', 0)),
+        domain=[
+            ('id', If(Eval('context', {}).contains('company'), '=', '!='),
+                Eval('context', {}).get('company', 0)),
             ])
     invoice_account = fields.Many2One('account.account', 'Invoice Account',
-            domain=[
-                ('company', '=', Eval('company')),
-                ('kind', '!=', 'view'),
+        domain=[
+            ('company', '=', Eval('company')),
+            ('kind', '!=', 'view'),
             ],
-            states={
-                'readonly': Or(Equal(Eval('type'), 'none'),
-                    Not(Bool(Eval('company')))),
-                'required': And(Not(Equal(Eval('type'), 'none')),
-                    Bool(Eval('company'))),
-            }, depends=['company'])
+        states={
+            'readonly': (Eval('type') == 'none') | ~Eval('company'),
+            'required': (Eval('type') != 'none') & Eval('company'),
+            },
+        depends=['company', 'type'])
     credit_note_account = fields.Many2One('account.account', 'Credit Note Account',
-            domain=[
-                ('company', '=', Eval('company')),
-                ('kind', '!=', 'view'),
+        domain=[
+            ('company', '=', Eval('company')),
+            ('kind', '!=', 'view'),
             ],
-            states={
-                'readonly': Or(Equal(Eval('type'), 'none'),
-                    Not(Bool(Eval('company')))),
-                'required': And(Not(Equal(Eval('type'), 'none')),
-                    Bool(Eval('company'))),
-            }, depends=['company', 'type'])
-
+        states={
+            'readonly': (Eval('type') == 'none') | ~Eval('company'),
+            'required': (Eval('type') != 'none') & Eval('company'),
+            },
+        depends=['company', 'type'])
     invoice_base_code = fields.Many2One('account.tax.code',
-            'Invoice Base Code',
-            states={
-                'readonly': Equal(Eval('type'), 'none'),
+        'Invoice Base Code',
+        states={
+            'readonly': Eval('type') == 'none',
             }, depends=['type'])
     invoice_base_sign = fields.Numeric('Invoice Base Sign', digits=(2, 0),
-            help='Usualy 1 or -1',
-            states={
-                'readonly': Equal(Eval('type'), 'none'),
+        help='Usualy 1 or -1',
+        states={
+            'readonly': Eval('type') == 'none',
             }, depends=['type'])
     invoice_tax_code = fields.Many2One('account.tax.code',
-            'Invoice Tax Code',
-            states={
-                'readonly': Equal(Eval('type'), 'none'),
+        'Invoice Tax Code',
+        states={
+            'readonly': Eval('type') == 'none',
             }, depends=['type'])
     invoice_tax_sign = fields.Numeric('Invoice Tax Sign', digits=(2, 0),
-            help='Usualy 1 or -1',
-            states={
-                'readonly': Equal(Eval('type'), 'none'),
+        help='Usualy 1 or -1',
+        states={
+            'readonly': Eval('type') == 'none',
             }, depends=['type'])
     credit_note_base_code = fields.Many2One('account.tax.code',
-            'Credit Note Base Code',
-            states={
-                'readonly': Equal(Eval('type'), 'none'),
+        'Credit Note Base Code',
+        states={
+            'readonly': Eval('type') == 'none',
             }, depends=['type'])
     credit_note_base_sign = fields.Numeric('Credit Note Base Sign', digits=(2, 0),
-            help='Usualy 1 or -1',
-            states={
-                'readonly': Equal(Eval('type'), 'none'),
+        help='Usualy 1 or -1',
+        states={
+            'readonly': Eval('type') == 'none',
             }, depends=['type'])
     credit_note_tax_code = fields.Many2One('account.tax.code',
-            'Credit Note Tax Code',
-            states={
-                'readonly': Equal(Eval('type'), 'none'),
+        'Credit Note Tax Code',
+        states={
+            'readonly': Eval('type') == 'none',
             }, depends=['type'])
     credit_note_tax_sign = fields.Numeric('Credit Note Tax Sign', digits=(2, 0),
-            help='Usualy 1 or -1',
-            states={
-                'readonly': Equal(Eval('type'), 'none'),
+        help='Usualy 1 or -1',
+        states={
+            'readonly': Eval('type') == 'none',
             }, depends=['type'])
     template = fields.Many2One('account.tax.template', 'Template')
 
@@ -702,7 +699,7 @@ class Tax(ModelSQL, ModelView):
         return Transaction().context.get('company') or False
 
     def on_change_with_currency_digits(self, vals):
-        company_obj = self.pool.get('company.company')
+        company_obj = Pool().get('company.company')
         if vals.get('company'):
             company = company_obj.browse(vals['company'])
             return company.currency.digits
@@ -799,8 +796,8 @@ class Tax(ModelSQL, ModelView):
                 tax id as value, used to convert template id into tax.
                 The dictionary is filled with new taxes
         '''
-        template_obj = self.pool.get('account.tax.template')
-        lang_obj = self.pool.get('ir.lang')
+        template_obj = Pool().get('account.tax.template')
+        lang_obj = Pool().get('ir.lang')
 
         if template2tax is None:
             template2tax = {}
@@ -919,7 +916,7 @@ class Line(ModelSQL, ModelView):
             required=True, select=1, ondelete='CASCADE')
 
     def on_change_with_currency_digits(self, vals):
-        move_line_obj = self.pool.get('account.move.line')
+        move_line_obj = Pool().get('account.move.line')
         if vals.get('move_line'):
             move_line = move_line_obj.browse(vals['move_line'])
             return move_line.currency_digits
@@ -977,8 +974,8 @@ class RuleTemplate(ModelSQL, ModelView):
                 tax rule. The dictionary is filled with new tax rules
         :return: id of the tax rule created
         '''
-        rule_obj = self.pool.get('account.tax.rule')
-        lang_obj = self.pool.get('ir.lang')
+        rule_obj = Pool().get('account.tax.rule')
+        lang_obj = Pool().get('ir.lang')
 
         if template2rule is None:
             template2rule = {}
@@ -1023,9 +1020,9 @@ class Rule(ModelSQL, ModelView):
     _description = __doc__
     name = fields.Char('Name', required=True, translate=True)
     company = fields.Many2One('company.company', 'Company', required=True,
-            select=1, domain=[
-                ('id', If(In('company', Eval('context', {})), '=', '!='),
-                    Get(Eval('context', {}), 'company', 0)),
+        select=1, domain=[
+            ('id', If(Eval('context', {}).contains('company'), '=', '!='),
+                Eval('context', {}).get('company', 0)),
             ])
     lines = fields.One2Many('account.tax.rule.line', 'rule', 'Lines')
     template = fields.Many2One('account.tax.rule.template', 'Template')
@@ -1040,8 +1037,8 @@ class Rule(ModelSQL, ModelView):
                 and match value as value
         :return: a list of the tax id to use or False
         '''
-        tax_obj = self.pool.get('account.tax')
-        rule_line_obj = self.pool.get('account.tax.rule.line')
+        tax_obj = Pool().get('account.tax')
+        rule_line_obj = Pool().get('account.tax.rule.line')
 
         if isinstance(rule, (int, long)) and rule:
             rule = self.browse(rule)
@@ -1067,8 +1064,8 @@ class Rule(ModelSQL, ModelView):
                 and tax rule id as value, used to convert template id into
                 tax rule. The dictionary is filled with new tax rules
         '''
-        template_obj = self.pool.get('account.tax.rule.template')
-        lang_obj = self.pool.get('ir.lang')
+        template_obj = Pool().get('account.tax.rule.template')
+        lang_obj = Pool().get('ir.lang')
 
         if template2rule is None:
             template2rule = {}
@@ -1113,17 +1110,19 @@ class RuleLineTemplate(ModelSQL, ModelView):
             ondelete='CASCADE')
     group = fields.Many2One('account.tax.group', 'Tax Group')
     origin_tax = fields.Many2One('account.tax.template', 'Original Tax',
-            domain=[
-                ('account', '=', Get(Eval('_parent_rule', {}), 'account')),
-                ('group', '=', Eval('group'))
+        domain=[
+            ('account', '=', Eval('_parent_rule', {}).get('account', 0)),
+            ('group', '=', Eval('group'))
             ],
-            help='If the original tax template is filled, the rule will be ' \
-                    'applied only for this tax template.')
+        help='If the original tax template is filled, the rule will be ' \
+            'applied only for this tax template.',
+        depends=['group'])
     tax = fields.Many2One('account.tax.template', 'Substitution Tax',
-            domain=[
-                ('account', '=', Get(Eval('_parent_rule', {}), 'account')),
-                ('group', '=', Eval('group')),
-            ])
+        domain=[
+            ('account', '=', Eval('_parent_rule', {}).get('account', 0)),
+            ('group', '=', Eval('group')),
+            ],
+        depends=['group'])
     sequence = fields.Integer('Sequence')
 
     def __init__(self):
@@ -1169,7 +1168,7 @@ class RuleLineTemplate(ModelSQL, ModelView):
                 tax rule lines
         :return: id of the tax rule line created
         '''
-        rule_line_obj = self.pool.get('account.tax.rule.line')
+        rule_line_obj = Pool().get('account.tax.rule.line')
 
         if template2rule_line is None:
             template2rule_line = {}
@@ -1206,17 +1205,19 @@ class RuleLine(ModelSQL, ModelView):
             select=1, ondelete='CASCADE')
     group = fields.Many2One('account.tax.group', 'Tax Group')
     origin_tax = fields.Many2One('account.tax', 'Original Tax',
-            domain=[
-                ('company', '=', Get(Eval('_parent_rule', {}), 'company')),
-                ('group', '=', Eval('group')),
+        domain=[
+            ('company', '=', Eval('_parent_rule', {}).get('company')),
+            ('group', '=', Eval('group')),
             ],
-            help='If the original tax is filled, the rule will be applied ' \
-                    'only for this tax.')
+        help='If the original tax is filled, the rule will be applied ' \
+            'only for this tax.',
+        depends=['group'])
     tax = fields.Many2One('account.tax', 'Substitution Tax',
-            domain=[
-                ('company', '=', Get(Eval('_parent_rule', {}), 'company')),
-                ('group', '=', Eval('group')),
-            ])
+        domain=[
+            ('company', '=', Eval('_parent_rule', {}).get('company')),
+            ('group', '=', Eval('group')),
+            ],
+        depends=['group'])
     sequence = fields.Integer('Sequence')
     template = fields.Many2One('account.tax.rule.line.template', 'Template')
 
@@ -1278,7 +1279,7 @@ class RuleLine(ModelSQL, ModelView):
                 id into tax rule line. The dictionary is filled with new
                 tax rule lines
         '''
-        template_obj = self.pool.get('account.tax.rule.line.template')
+        template_obj = Pool().get('account.tax.rule.line.template')
 
         if template2rule_line is None:
             template2rule_line = {}
@@ -1323,10 +1324,11 @@ class OpenCode(Wizard):
     }
 
     def _action_open_code(self, data):
-        model_data_obj = self.pool.get('ir.model.data')
-        act_window_obj = self.pool.get('ir.action.act_window')
-        fiscalyear_obj = self.pool.get('account.fiscalyear')
-        period_obj = self.pool.get('account.period')
+        pool = Pool()
+        model_data_obj = pool.get('ir.model.data')
+        act_window_obj = pool.get('ir.action.act_window')
+        fiscalyear_obj = pool.get('account.fiscalyear')
+        period_obj = pool.get('account.period')
 
         if not Transaction().context.get('fiscalyear'):
             fiscalyear_ids = fiscalyear_obj.search([
